@@ -266,7 +266,9 @@ def seg_file2tensor_3band(f, TARGET_SIZE):  # , resize):
 
 # =========================================================
 def do_seg(
-    f, M, metadatadict, sample_direc, NCLASSES, N_DATA_BANDS, TARGET_SIZE, TESTTIMEAUG, WRITE_MODELMETADATA, do_crf
+    f, M, metadatadict, sample_direc, 
+    NCLASSES, N_DATA_BANDS, TARGET_SIZE, TESTTIMEAUG, WRITE_MODELMETADATA,
+    DO_CRF, OTSU_THRESHOLD
 ):
 
     if f.endswith("jpg"):
@@ -293,7 +295,7 @@ def do_seg(
         metadatadict["nclasses"] = NCLASSES
         metadatadict["n_data_bands"] = N_DATA_BANDS
 
-    if NCLASSES == 1:
+    if NCLASSES == 2:
 
         if N_DATA_BANDS <= 3:
             image, w, h, bigimage = seg_file2tensor_3band(f, TARGET_SIZE)
@@ -366,21 +368,27 @@ def do_seg(
         if WRITE_MODELMETADATA:
             metadatadict["av_softmax_scores"] = softmax_scores
 
-        if do_crf:
+        if DO_CRF:
             est_label, l_unique = crf_refine(softmax_scores, bigimage, NCLASSES+1, 1, 1, 2)
 
             est_label = est_label-1
             if WRITE_MODELMETADATA:
                 metadatadict["otsu_threshold"] = np.nan
 
-        else:
+        elif OTSU_THRESHOLD:
             thres = threshold_otsu(est_label)
             # print("Class threshold: %f" % (thres))
             est_label = (est_label > thres).astype("uint8")
             if WRITE_MODELMETADATA:
                 metadatadict["otsu_threshold"] = thres
 
-    else:  ###NCLASSES>1
+        else:
+            # print("Not using Otsu threshold")
+            est_label = (est_label > 0.5).astype("uint8")
+            if WRITE_MODELMETADATA:
+                metadatadict["otsu_threshold"] = 0.5            
+
+    else:  ###NCLASSES>2
 
         if N_DATA_BANDS <= 3:
             image, w, h, bigimage = seg_file2tensor_3band(
@@ -440,7 +448,7 @@ def do_seg(
         if WRITE_MODELMETADATA:
             metadatadict["av_softmax_scores"] = softmax_scores
 
-        if do_crf:
+        if DO_CRF:
             est_label, l_unique = crf_refine(softmax_scores, bigimage, NCLASSES, 1, 1, 2)
 
             est_label = est_label-1
@@ -450,8 +458,6 @@ def do_seg(
         else:
             est_label = np.argmax(softmax_scores, -1)
 
-
-
     # heatmap = resize(heatmap,(w,h), preserve_range=True, clip=True)
 
     class_label_colormap = [
@@ -468,10 +474,10 @@ def do_seg(
     ]
     # add classes for more than 10 classes
 
-    if NCLASSES > 1:
-        class_label_colormap = class_label_colormap[:NCLASSES]
-    else:
-        class_label_colormap = class_label_colormap[:2]
+    # if NCLASSES > 1:
+    class_label_colormap = class_label_colormap[:NCLASSES]
+    # else:
+    #     class_label_colormap = class_label_colormap[:2]
 
     if WRITE_MODELMETADATA:
         metadatadict["color_segmentation_output"] = segfile
@@ -545,16 +551,16 @@ def do_seg(
         plt.imshow(bigimage, cmap='gray')
     else:
         plt.imshow(bigimage[:, :, :3])
-    if NCLASSES>1:
+    if NCLASSES>2:
         plt.imshow(color_label, alpha=0.5)
-    else:
+    elif NCLASSES==2:
         cs = plt.contour(est_label, [-99,0,99], colors='r')
     plt.axis("off")
     # plt.show()
     plt.savefig(segfile, dpi=200, bbox_inches="tight")
     plt.close("all")
 
-    if NCLASSES==1:
+    if NCLASSES==2:
         segfile = segfile.replace("_overlay.png", "_result.mat")
         p = cs.collections[0].get_paths()[0]
         v = p.vertices
